@@ -1,5 +1,6 @@
 import torch as _torch
 import sys as _sys
+import random as _random
 
 grad_precision_bit = 16
 grad_file_ext = '.npy'  # numpy
@@ -15,3 +16,5 @@ gpu_available = _torch.cuda.is_available()
 num_gpus = _torch.cuda.device_count()
 
 data_load_lim = _sys.maxsize
+
+current_seed = _random.randint(0, 2**24)
