@@ -5,6 +5,7 @@
 """
 
 import json as _json
+import math as _math
 from collections import OrderedDict as _ODict
 from os import sep as _sep
 
@@ -13,11 +14,10 @@ import torch as _torch
 import coinstac_dinunet.config as _conf
 import coinstac_dinunet.data as _data
 import coinstac_dinunet.metrics as _base_metrics
-import coinstac_dinunet.utils.tensorutils as _tu
-from coinstac_dinunet.config.status import *
 import coinstac_dinunet.utils as _utils
+import coinstac_dinunet.utils.tensorutils as _tu
 import coinstac_dinunet.vision.plotter as _plot
-import math as _math
+from coinstac_dinunet.config.status import *
 
 
 class NNTrainer:
@@ -158,7 +158,7 @@ class NNTrainer:
         return it
 
     def train_local(self, dataset_cls, **kw):
-        cache = {}
+        cache = {'seed': self.cache['seed']}
         out = {}
         self._set_monitor_metric()
         self._set_log_headers()
@@ -176,7 +176,7 @@ class NNTrainer:
 
         local_iter = self.cache.get('local_iterations', 1)
         epochs = self.cache.get('pretrain_epochs', self.cache['epochs'])
-        for ep in range(epochs):
+        for ep in range(1, epochs + 1):
             for k in self.nn:
                 self.nn[k].train()
 
@@ -209,14 +209,16 @@ class NNTrainer:
             cache['validation_scores'].append([*val_avg.get(), *val_metrics.get()])
             out.update(**self._save_if_better(ep, val_metrics))
             self._on_epoch_end(ep, ep_avg, ep_metrics, val_avg, val_metrics)
-            self._plot_progress(cache, epoch=ep)
+
+            if ep % int(_math.log(ep + 1) + 1) == 0:
+                self._plot_progress(cache, epoch=ep)
+
             if self._stop_early(epoch=ep, epoch_averages=ep_avg, epoch_metrics=ep_metrics,
                                 validation_averages=val_avg, validation_metric=val_metrics):
                 break
 
         cache['best_local_epoch'] = self.cache['best_local_epoch']
         cache['best_local_score'] = self.cache['best_local_score']
-        _utils.save_scores(cache, self.cache['log_dir'], file_keys=['train_scores', 'validation_scores'])
         _utils.save_cache(cache, self.cache['log_dir'])
         return out
 
