@@ -4,7 +4,9 @@
 @ref: https://github.com/sraashis/easytorch
 """
 
+import math as _math
 import os as _os
+import random as _rd
 
 import matplotlib.pyplot as _plt
 import numpy as _np
@@ -14,8 +16,11 @@ from sklearn.preprocessing import MinMaxScaler as _MinMaxScaler
 _plt.switch_backend('agg')
 _plt.rcParams["figure.figsize"] = [16, 9]
 
+_COLORS = ['black', 'darkslateblue', 'maroon', 'magenta', 'teal', 'red', 'blue', 'blueviolet', 'brown', 'cadetblue',
+           'chartreuse', 'coral', 'cornflowerblue', 'indigo', 'cyan', 'navy']
 
-def plot_progress(cache, log_dir, plot_keys=[], num_points=11, epoch=None):
+
+def plot_progress(cache, log_dir, plot_keys=[], num_points=31, epoch=None):
     r"""
     Custom plot to plot data from the cache by keys.
     """
@@ -45,18 +50,25 @@ def plot_progress(cache, log_dir, plot_keys=[], num_points=11, epoch=None):
             if max(df[col]) > 1:
                 df[col] = scaler.fit_transform(df[[col]])
 
+        _rd.seed(cache['seed'])
+        color = _rd.sample(_COLORS, n_cols)
+
         rollin_window = max(df.shape[0] // num_points + 1, 3)
+        ax = df.plot(x_compat=True, alpha=0.11, legend=0, color=color)
+
         rolling = df.rolling(rollin_window, min_periods=1).mean()
-        ax = df.plot(x_compat=True, alpha=0.2, legend=0)
-        rolling.plot(ax=ax, title=k.upper())
+        rolling.plot(ax=ax, title=k.upper(), color=color)
 
         if epoch and epoch != df.shape[0]:
             """
             Set correct epoch as x-tick-labels.
             """
             xticks = list(range(0, df.shape[0], df.shape[0] // epoch)) + [df.shape[0] - 1]
+            step = int(_math.log(len(xticks) + 1) + len(xticks)//num_points + 1)
+            xticks_range = list(range(len(xticks)))[::step]
+            xticks = xticks[::step]
             ax.set_xticks(xticks)
-            ax.set_xticklabels(list(range(len(xticks))))
+            ax.set_xticklabels(xticks_range)
 
         _plt.xlabel('Epochs')
         _plt.savefig(log_dir + _os.sep + f"{k}.png")
